<?php

/**
 * Loading VTCore Files
 * Without this the layout will break
 * and additional plugins wont be loaded
 */
if (!function_exists('vtcore_start')) {
  include_once('vtcore/core/vtcore.inc.php');
}

/**
 * Implements hook_theme_registry_alter()
 */
function sigmaone_theme_registry_alter(&$theme_registry) {
  $plugins = vtcore_scan_plugin();
  foreach ($theme_registry as $theme_name => $themedata) {
    foreach ($plugins as $plugin_name => $data) {
      if ($data['status'] == 0) {
        continue;
      }
      $theme_registry[$theme_name]['preprocess functions'][] = $plugin_name . '_vtcore_preprocess_' . $theme_name;
      $theme_registry[$theme_name]['process functions'][] = $plugin_name . '_vtcore_process_' . $theme_name;
    }
  }
}

/**
 * Implements hook_css_alter()
 */
function sigmaone_css_alter(&$css) {
  // create a new hook for plugin to preprocess $variables;
  vtcore_alter_process('vtcore_css', $css);
}

/**
 * Implements hook_js_alter()
 */
function sigmaone_js_alter(&$javascript) {
  // create a new hook for plugin to preprocess $variables;
  vtcore_alter_process('vtcore_js', $javascript);
}

/**
 * Implements hook_block_view_alter()
 */
function sigmaone_block_view_alter(&$data, $block) {
  // create a new hook for plugin to preprocess $variables;
  vtcore_alter_process('vtcore_block_view', $data, $block);
}

/**
 * Implements hook_form_alter()
 */
function sigmaone_form_alter(&$form, &$form_state, $form_id) {
  // create a new hook for plugin to preprocess $variables;
  vtcore_alter_process('vtcore_form', $form, $form_state, $form_id);
}

/**
 * Implements theme_breadcrumb()
 */
function sigmaone_breadcrumb(&$variables) {
  // create a new hook for plugin to preprocess $variables;
  vtcore_alter_process('vtcore_breadcrumb', $variables);

  return $variables['breadcrumb'];
}

/**
 * Implements hook_theme()
 */
function sigmaone_theme($existing, $type, $theme, $path) {
  $variables = array();

  // Generic table for form
  $variables['tableform'] = array(
    'function' => 'sigma_vtcore_tableform',
    'type' => 'theme_engine',
    'render element' => 'element',
  );

  vtcore_alter_process('vtcore_theme', $variables, $path);
  return $variables;
}

/**
 * Changes the default meta content-type tag to the shorter HTML5 version
 */
function sigmaone_html_head_alter(&$head_elements) {
  $head_elements['system_meta_content_type']['#attributes'] = array(
    'charset' => 'utf-8'
  );
}

/**
 * Override or insert variables into the html template.
 */
function sigmaone_preprocess_html(&$variables) {
  drupal_add_css(path_to_theme() . '/css/ie7-fixes.css', array('group' => CSS_THEME, 'browsers' => array('IE' => 'IE 7', '!IE' => FALSE), 'preprocess' => FALSE));
}

/**
 * Override or insert variables into the page template.
 */
function sigmaone_preprocess_page(&$variables) {
  // set admin variables
  $variables['admin_page'] = FALSE;

  $path = current_path();
  if (path_is_admin($path)) {
    $variables['admin_page'] = TRUE;
    $variables['page']['#attributes']['class'][] = 'admin-page';
    $variables['page']['#attributes']['class'][] = BASE_THEME;
  }

  $variables['page']['#attributes']['id'] = 'page';

  // decode html entity in title
  $variables['title'] = html_entity_decode(drupal_get_title());

  // additional global variables for marking overlay mode
  $variables['overlay'] = FALSE;
  if (module_exists('overlay') && overlay_get_mode() == 'child') {
    $variables['overlay'] = TRUE;
  }

  // Operate if not on admin page
  if ($variables['admin_page'] == FALSE || $variables['overlay'] == FALSE) {
    // Remove shortcut if not on admin page
    unset($variables['title_suffix']['add_or_remove_shortcut']);
  }
}

/**
 * Theme fieldset
 */
function sigmaone_fieldset($variables) {
  $element = $variables['element'];
  element_set_attributes($element, array('id'));
  _form_set_class($element, array('form-wrapper'));

  $output = '<fieldset' . drupal_attributes($element['#attributes']) . '>';
  if (!empty($element['#title'])) {
    // Always wrap fieldset legends in a SPAN for CSS positioning.
    $output .= '<legend><span class="fieldset-legend">' . $element['#title'] . '</span></legend>';
  }
  $output .= '<div class="fieldset-wrapper clearfix">';
  if (!empty($element['#description'])) {
    $output .= '<div class="fieldset-description">' . $element['#description'] . '</div>';
  }
  $output .= $element['#children'];
  if (isset($element['#value'])) {
    $output .= $element['#value'];
  }
  $output .= '</div>';
  $output .= "</fieldset>\n";
  return $output;
}



/**
 * Implements hook_process_html()
 */
function sigmaone_process_html(&$variables) {
  // Hook into color.module.
  if (module_exists('color')) {
    _color_html_alter($variables);
  }
}

/**
 * Implements hook_process_page()
 */
function sigmaone_process_page(&$variables) {
  // Hook into color.module.
  if (module_exists('color')) {
    _color_page_alter($variables);
  }
}

/**
 * Addtional theme for theming form as a table
 *
 * Currently it will support if the form array structure is :
 *
 * $form['container'] = array(
 * 	'#type' => 'container',
 * 	'#theme' => 'themeform',
 * 	'#header' => array(array of headers);
 * );
 *
 * $form['container'][]['something'] = array( .... );
 * $form['container'][]['something']['something'] = array( .... );
 *
 * Note : Only tested for 2 level of nesting and only 1 containers
 *
 * @todo : add features for table id, draggable, sortable, row id, etc
 */
function sigma_vtcore_tableform(&$variables) {
  $element = $variables['element'];
  $header = $element['#header'];

  // Loop into children to build the row
  $rows = array();

  foreach (element_children($element) as $key) {
    $row = array();
    $row_element = $element[$key];

    foreach (element_children($row_element) as $cell_key) {
      $cell_element = $row_element[$cell_key];

      // This is for form element type value.
      if (isset($cell_element['#type']) && $cell_element['#type'] == 'value') {
        $row[] = $cell_element['#value'];
      }

      // This is for other form element.
      if (isset($cell_element['#type']) && $cell_element['#type'] != 'value') {
        unset($cell_element['#title']);
        $row[] = drupal_render($cell_element);
      }

      // Probably we got another children element
      // @Todo : do we need to utilize infinite looping to grab all children level?
      if (!isset($cell_element['#type'])) {
        foreach (element_children($cell_element) as $subcell_key) {
          $subcell_element = $cell_element[$subcell_key];

          // This is for form element type value.
          if (isset($subcell_element['#type']) && $subcell_element['#type'] == 'value') {
            $row[] = $subcell_element['#value'];
          }

          // This is for other form element.
          if (isset($subcell_element['#type']) && $subcell_element['#type'] != 'value') {
            unset($subcell_element['#title']);
            $row[] = drupal_render($subcell_element);
          }
        }
      }
    }

    $rows[] = array('data' => $row);
  }

  return theme('table', array('header' => $header, 'rows' => $rows));

}